@@ -6,14 +6,18 @@ It also contains a decorator to mark methods as rpc methods.
 '''
 
 import inspect
-import platform
 import pydoc
 import types
-import xmlrpclib
-from xmlrpclib import Fault
 from django.contrib.auth import authenticate, login, logout
-from jsonrpcdispatcher import JSONRPCDispatcher, json
-from xmlrpcdispatcher import XMLRPCDispatcher
+from .jsonrpcdispatcher import JSONRPCDispatcher, json
+from .xmlrpcdispatcher import XMLRPCDispatcher
+
+try:
+    # Python2.x
+    from xmlrpclib import Fault, loads, ServerProxy
+except ImportError:
+    # Python3
+    from xmlrpc.client import Fault, loads, ServerProxy
 
 # this error code is taken from xmlrpc-epi
 # http://xmlrpc-epi.sourceforge.net/specs/rfc.fault_codes.php
@@ -113,7 +117,12 @@ class RPCMethod(object):
         elif name is not None:
             self.name = name
         else:
-            self.name = method.func_name
+            try:
+                # Python2
+                self.name = method.func_name
+            except AttributeError:
+                # Python3
+                self.name = method.__name__
 
         # get the help string for each method
         if docstring is not None:
@@ -134,7 +143,7 @@ class RPCMethod(object):
         self.signature.insert(0, 'object')
 
         if hasattr(method, 'signature') and \
-             len(method.signature) == len(self.args) + 1:
+           len(method.signature) == len(self.args) + 1:
             # use the @rpcmethod signature if it has the correct
             # number of args
             self.signature = method.signature
@@ -154,13 +163,13 @@ class RPCMethod(object):
         plist = ['"' + param['name'] + '"' for param in params]
 
         jsonlist = [
-                   '{',
-                   '"id": "djangorpc",',
-                   '"method": "' + self.name + '",',
-                   '"params": [',
-                   '   ' + ','.join(plist),
-                   ']',
-                   '}',
+            '{',
+            '"id": "djangorpc",',
+            '"method": "' + self.name + '",',
+            '"params": [',
+            '   ' + ','.join(plist),
+            ']',
+            '}',
         ]
 
         return '\n'.join(jsonlist)
@@ -184,13 +193,13 @@ class RPCMethod(object):
             arglist = []
             if len(self.signature) == len(self.args) + 1:
                 for argnum in range(len(self.args)):
-                    arglist.append({'name': self.args[argnum], \
-                                    'rpctype': self.signature[argnum+1]})
+                    arglist.append({'name': self.args[argnum],
+                                    'rpctype': self.signature[argnum + 1]})
                 return arglist
             else:
                 # this should not happen under normal usage
                 for argnum in range(len(self.args)):
-                    arglist.append({'name': self.args[argnum], \
+                    arglist.append({'name': self.args[argnum],
                                     'rpctype': 'object'})
                 return arglist
         return []
@@ -226,8 +235,7 @@ class RPCDispatcher(object):
     '''
 
     def __init__(self, url='', apps=[], restrict_introspection=False,
-            restrict_ootb_auth=True, json_encoder=None):
-        version = platform.python_version_tuple()
+                 restrict_ootb_auth=True, json_encoder=None):
         self.url = url
         self.rpcmethods = []        # a list of RPCMethod objects
         self.jsonrpcdispatcher = JSONRPCDispatcher(json_encoder)
@@ -257,7 +265,7 @@ class RPCDispatcher(object):
         description['methods'] = [{'name': method.name,
                                    'summary': method.help,
                                    'params': method.get_params(),
-                                   'return': method.get_returnvalue()} \
+                                   'return': method.get_returnvalue()}
                                   for method in self.rpcmethods]
 
         return description
@@ -285,7 +293,7 @@ class RPCDispatcher(object):
         # this differs from what implementation in SimpleXMLRPCServer does
         # this will report via a fault or error while SimpleXMLRPCServer
         # just returns an empty string
-        raise Fault(APPLICATION_ERROR, 'No method found with name: ' + \
+        raise Fault(APPLICATION_ERROR, 'No method found with name: ' +
                     str(method_name))
 
     @rpcmethod(name='system.methodSignature', signature=['array', 'string'])
@@ -297,7 +305,7 @@ class RPCDispatcher(object):
         for method in self.rpcmethods:
             if method.name == method_name:
                 return method.signature
-        raise Fault(APPLICATION_ERROR, 'No method found with name: ' + \
+        raise Fault(APPLICATION_ERROR, 'No method found with name: ' +
                     str(method_name))
 
     @rpcmethod(name='system.login', signature=['boolean', 'string', 'string'])
@@ -346,11 +354,11 @@ class RPCDispatcher(object):
 
             for obj in dir(app):
                 method = getattr(app, obj)
-                if isinstance(method, xmlrpclib.ServerProxy):
+                if isinstance(method, ServerProxy):
                     continue
                 if callable(method) and \
                    hasattr(method, 'is_rpcmethod') and \
-                   method.is_rpcmethod == True:
+                   method.is_rpcmethod is True:
                     # if this method is callable and it has the rpcmethod
                     # decorator, add it to the dispatcher
                     self.register_method(method, method.external_name)
@@ -359,14 +367,12 @@ class RPCDispatcher(object):
                     # scan the module for methods with @rpcmethod
                     self.register_rpcmethods(["%s.%s" % (appname, obj)])
 
-
-
     def jsondispatch(self, raw_post_data, **kwargs):
         '''
         Sends the post data to :meth:`rpc4django.jsonrpcdispatcher.JSONRPCDispatcher.dispatch`
         '''
 
-        return self.jsonrpcdispatcher.dispatch(raw_post_data, **kwargs)
+        return self.jsonrpcdispatcher.dispatch(raw_post_data.decode('utf-8'), **kwargs)
 
     def xmldispatch(self, raw_post_data, **kwargs):
         '''
@@ -385,14 +391,14 @@ class RPCDispatcher(object):
             # xmlrpclib.loads could throw an exception, but this is fine
             # since _marshaled_dispatch would throw the same thing
             try:
-                params, method = xmlrpclib.loads(raw_post_data)
+                params, method = loads(raw_post_data.decode('utf-8'))
                 return method
             except Exception:
                 return None
         else:
             try:
                 # attempt to do a json decode on the data
-                jsondict = json.loads(raw_post_data)
+                jsondict = json.loads(raw_post_data.decode('utf-8'))
                 if not isinstance(jsondict, dict) or 'method' not in jsondict:
                     return None
                 else:
